==> argvanalysis-0.1.tar.gz: argvanalysis-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'argvanalysis',         # How you named your package folder (MyLib)
  packages = ['argvanalysis'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Used to read argv in a spesific order "-key num"',   # Give a short description about your library
  author = 'Harald Wilhelmsen',                   # Type in your name
  author_email = 'Wil.harald@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/HaraldWilhelmsen/argvanalysis',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/HaraldWilhelmsen/argvanalysis/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['argvalues'],   # Keywords that define your package best
  install_requires=[],            # I get to this in a second
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> argvanalysis-1.0.1.tar.gz: argvanalysis-1.0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'argvanalysis',         # How you named your package folder (MyLib)
  packages = ['argvanalysis'],   # Chose the same as "name"
  version = '1.0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Used to read argv in a spesific order "-key num"',   # Give a short description about your library
  author = 'Harald Wilhelmsen',                   # Type in your name
  author_email = 'Wil.harald@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/HaraldWilhelmsen/argvanalysis',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/HaraldWilhelmsen/argvanalysis/archive/v1.0.1.tar.gz',    # I explain this later on
  keywords = ['argvalues'],   # Keywords that define your package best
  install_requires=[],            # I get to this in a second
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
